<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Базовый загрузчик</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Получить список</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>URL-адрес:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Начать загрузку</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Форматирование</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Расширение</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примечание</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Плагин:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Вставить содержимое буфера</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Недавно использованные</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Установить параметры загрузки</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Пакетный загрузчик</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Миниатюра</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>URL для загрузки</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Вставить URL из буфера</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Мониторить URL в буфере</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Добавить URL в список</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Установить</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Загрузчик плейлистов</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Параметры загрузки:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Время начала (HH:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Время окончания (HH:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Главы (через запятую):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Разделить по главам</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>URL плейлиста:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Очистить внутренний архивный файл</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Использовать внутренний архивный файл</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Выше</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Домой</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Общие параметры</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Показывать значок в трее</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Автосохранение списка незагруженных медиа</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Скрывать загруженные</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Сбросить параметры до начальных</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Сброс</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Пресеты параметров</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Путь загрузки</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Выбрать язык</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Использовать свои настройки прокси</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Получить настройки прокси из окружения</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Без прокси</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Параметры плагина по умолчанию</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Параметры списка:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Подписки</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Имя UI</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Включить вкладку &apos;Библиотека&apos;</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Максимум одновременных загрузок</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Кодировка текста заголовков</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>Показывать текущую версию и автообновить</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>Показать текущую и доступную версии</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>Показать текущую версию</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>Ничего не делать</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>Действия после старта</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Плагин</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Новая строка</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Mенеджер адресов</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Параметры загрузки</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Привязка URL к плагину</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Фильтр URL</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Настройки прокси</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>Использовать системные настройки прокси</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Ручная настройка прокси
Пример 1: 192.168.93.89:8080
Пример 2: ${gateway}:8080</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>Воспроизвести загруженное медиа</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>Введите URL плейлиста или несколько URL, разделенных пробелом или новой строкой</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Переименовать файл</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>Открыть папку загрузок</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>Открыть папку с темой</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>Открыть папку расширений</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>Хотите сбросить эти параметры на значения по умолчанию?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Имя веб-браузера для получения cookies</translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation>Тема (необходим перезапуск)</translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation>Переключить (имя браузера - путь к файлу cookie)</translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation>Показывать метаданные в пакетном загрузчике</translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation>Автозагрузка добавленного в пакетный загрузчик</translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation>Уведомить по окончании загрузки</translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation>Уведомить по окончании всех загрузок</translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation>Настройки плагинов</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Расширения</translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation>Удалить расширение</translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation>Обновить расширение</translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation>Добавить расширение</translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation>Открыть папку бинарников</translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation>Открыть папку расширений</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>Предустановка %1</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Имя файла с расширением &apos;.txt&apos; сохранит только URL-адреса</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Скрыть строку</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Показать все скрытые строки</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>Не удалось запустить исполняемый файл %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копировать URL</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>Открыть URL в %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>Копировать URL %1</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Сохранить список в файл</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Ответы на</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Сохранить субтитры в файл</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Плагин:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Получить список из файла</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Пресеты параметров</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Открыть папку загрузки</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>Страница проекта</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Авторское право</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Электронная почта</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Версия Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Эта программа является бесплатным ПО; вы можете распространять его и/или изменять в соответствии с условиями GNU General Public License, опубликованной Free Software Foundation; либо версией 2 этой лицензии, либо (по вашему выбору) любой более поздней версией.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Эта программа распространяется в надежде, что она окажется полезной, но БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ; даже без подразумеваемых гарантий КОММЕРЧЕСКОЙ ПРИГОДНОСТИ или ПРИГОДНОСТИ ДЛЯ ОПРЕДЕЛЕННЫХ ЦЕЛЕЙ. Более подробную информацию см. в GNU General Public License</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Ошибка, не удалось найти исполняемый файл для серверной части &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Для плагина &quot;%1&quot; требуется по крайней мере &quot;%2&quot; версия Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Чтобы отключить эти проверки, сделайте следующее:</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Перейдите на вкладку &quot;Настройка&quot;</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Перейдите на суб-вкладку &quot;Общие параметры&quot;</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. Нажмите &quot;Действия при старте&quot;</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. Выберите &quot;Ничего не делать&quot;</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Запуск в портативном режиме</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Запуск в режиме установки</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Путь загрузки: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Путь к данным приложения: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Установка адреса прокси: %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Сброс адреса прокси</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Ошибка, не удалось проанализировать конфигурационный файл &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Не удалось загрузить плагин</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Не удалось найти исполняемый файл &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Не удалось найти исполняемый файл python3 для серверной части &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Произошла ошибка сети</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>Url не поддерживается</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Загрузка отменена</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Код ошибки</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Ошибка загрузки, не удалось запустить плагин</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Ошибка загрузки, сбой плагина</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Форматирование</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Расширение</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примечание</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Не удалось открыть файл для записи</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Не удалось открыть файл для чтения</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Прошедшее время:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Не удалось найти информацию о версии, убедитесь, что &quot;%1&quot; установлен и работает правильно</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Найдена версия</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Не удалось открыть путь для записи: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Извлечение не удалось</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Сеть не отвечает %1 сек.</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Не удалось загрузить, не удается создать путь: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Начать загрузку</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>Проблема, не удалось удалить папку: %1</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Не удалось найти исполняемый файл &quot;bsdtar.exe&quot;</translation>
    </message>
    <message>
        <source>Failed To Find &quot;tar&quot; Executable</source>
        <translation>Не удалось найти исполняемый файл &quot;tar&quot;</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Не удалось загрузить</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Не удалось проанализировать JSON-файл из github</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Загружается</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Место назначения</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Обновление завершено, перезапустите, чтобы использовать новую версию</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Файл не найден</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Загрузка завершена</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Распаковка архива: </translation>
    </message>
    <message>
        <source>Renaming file to: </source>
        <translation>Переименовать файл как: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Обработка</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Загрузка завершена</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Сброс папки загрузки на по умолчанию</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Постобработка</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Форсировать загрузку</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Показать окно журнала</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Дата размещения:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Продолжительность:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Название субтитров</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Параметры загрузки</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Доп. параметры загрузки</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Время загрузки</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Скачать главы</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Разделить по главам</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Медиа уже в архиве</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темная</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Оставшееся время</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Загружен</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 уже загружено</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Это может занять очень много времени</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Скорость:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>Есть обновление для %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>Новая версия %1, обновление</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Проверка установленной версии %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Ваша версия: %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>Новя версия: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Обновите &quot;%1&quot; По крайней мере до версии &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Запрошенный формат недоступен</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>Введен неверный URL</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Только лучшее доступное аудио</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Только лучшее доступное аудио (MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Лучшее доступное аудио и видео</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Лучшее аудио с разрешением видео %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Внимание: Пропуск содержимого буфера обмена</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>Сначала папки</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>Упорядочить по возрастанию</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>Упорядочить по дате</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>Упорядочить по имени</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>Упорядочить по убыванию</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>Нет фильтра</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>Другие сайты</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>Извлечь аудио</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>Извлечь аудио как MP3</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>Только лучшее доступное аудио + миниатюра</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>Youtube</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>Автообновление отключено для %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>Новая версия %1, автообновление отключено</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Автор: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>Кол-во лайков: %1</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>Войдите, чтобы подтвердить, что вы не бот</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation>Показать/скрыть эл.управления</translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation>Объединение аудио и видео</translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation>Remuxing видео</translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation>Системная</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светлая</translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation>Не удалось переименовать</translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation>Завершено: %1, Выполняется: %2, Не начато: %3, Успешно: %4, Не удалось: %5, Отменено: %6</translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation>Остановлено, медиа уже есть в архиве</translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation>Открыть URL в %2</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Плеер по умолчанию</translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation>Внимание, ничего не загружено</translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation>Загрузка отменена, URL плейлистов не допускаются на этой вкладке</translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation>Загрузка отменена, не выполнено условие</translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation>Ошибка загрузки, неизвестная причина</translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation>Ошибка загрузки, проблема с сетью</translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>Скрыть список</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Установить пакетный файл</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Загрузка комментариев</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Начать загрузку</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копировать URL</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Убрать</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Показать субтитры</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Показать комментарии</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Показать параметры медиа</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Загрузить часть мультимедиа</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Установить</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Загрузка субтитров</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>Сортировать по возрастанию даты</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>Сортировать по убыванию даты</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>Сортировать по лайкам</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Установить по умолчанию</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Убрать</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Выберите файл плагина</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Установить папку загрузки</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Сброс</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation>Выберите файл cookie</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Имя веб-браузера для получения cookies</translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation>Путь к файлу cookie</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Удалить все</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>Хотите удалить указанный файл?</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>Хотите удалить указанную папку?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>Хотите удалить все файлы и папки?</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Переименовать текст</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>Переименовать папку</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation>Хотите удалить выбранные элементы?</translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Окно журнала</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Убрать</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Скрыть элементы управления</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Параметры списка:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копировать URL</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Показать комментарии</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Показать все обновленные</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Загрузить все обновленные</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Управление подписками</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Кол-во загруженных страниц</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Загрузка информации о видео</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Показать элементы управления</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Показать</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Это может занять очень много времени</translation>
    </message>
</context>
</TS>
